@@ -43,11 +43,6 @@ import java.io.OutputStream;
  *   <li> optionally write additional data, provided format supports it,</li>
  *   <li>{@link #close()}.</li>
  * </ul>
- * 
- * <p>
- * Example usage:<br/>
- * TBA
- * </p>
  */
 public abstract class ArchiveOutputStream extends OutputStream {
 
@@ -65,14 +60,14 @@ public abstract class ArchiveOutputStream extends OutputStream {
      * {@link #closeArchiveEntry()} to complete the process.
      * 
      * @param entry describes the entry
-     * @throws IOException
+     * @throws IOException if an I/O error occurs
      */
     public abstract void putArchiveEntry(ArchiveEntry entry) throws IOException;
 
     /**
      * Closes the archive entry, writing any trailer information that may
      * be required.
-     * @throws IOException
+     * @throws IOException if an I/O error occurs
      */
     public abstract void closeArchiveEntry() throws IOException;
 
@@ -87,11 +82,11 @@ public abstract class ArchiveOutputStream extends OutputStream {
     /**
      * Create an archive entry using the inputFile and entryName provided.
      * 
-     * @param inputFile
-     * @param entryName 
+     * @param inputFile the file to create the entry from
+     * @param entryName name to use for the entry
      * @return the ArchiveEntry set up with details from the file
      * 
-     * @throws IOException
+     * @throws IOException if an I/O error occurs
      */
     public abstract ArchiveEntry createArchiveEntry(File inputFile, String entryName) throws IOException;
 
@@ -163,10 +158,12 @@ public abstract class ArchiveOutputStream extends OutputStream {
      * <p>Some archive formats support variants or details that are
      * not supported (yet).</p>
      *
-     * <p>This implementation always returns true.
+     * @param archiveEntry
+     *            the entry to test
+     * @return This implementation always returns true.
      * @since 1.1
      */
-    public boolean canWriteEntryData(ArchiveEntry ae) {
+    public boolean canWriteEntryData(ArchiveEntry archiveEntry) {
         return true;
     }
 }
