@@ -141,7 +141,7 @@ import org.apache.commons.compress.archivers.ArchiveEntry;
  * N.B. does not handle the cpio "tar" format
  * </p>
  * @NotThreadSafe
- * @see "http://people.freebsd.org/~kientzle/libarchive/man/cpio.5.txt"
+ * @see <a href="http://people.freebsd.org/~kientzle/libarchive/man/cpio.5.txt">http://people.freebsd.org/~kientzle/libarchive/man/cpio.5.txt</a>
  */
 public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
 
@@ -192,14 +192,14 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      * 
      * @param format
      *            The cpio format for this entry.
-     * <br/>
-     * Possible format values are:
      * <p>
-     * CpioConstants.FORMAT_NEW<br/>
-     * CpioConstants.FORMAT_NEW_CRC<br/>
-     * CpioConstants.FORMAT_OLD_BINARY<br/>
-     * CpioConstants.FORMAT_OLD_ASCII<br/>
-     * 
+     * Possible format values are:
+     * <pre>
+     * CpioConstants.FORMAT_NEW
+     * CpioConstants.FORMAT_NEW_CRC
+     * CpioConstants.FORMAT_OLD_BINARY
+     * CpioConstants.FORMAT_OLD_ASCII
+     * </pre>
      */
     public CpioArchiveEntry(final short format) {
         switch (format) {
@@ -243,13 +243,14 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      *            The cpio format for this entry.
      * @param name
      *            The name of this entry.
-     * <br/>
-     * Possible format values are:
      * <p>
-     * CpioConstants.FORMAT_NEW<br/>
-     * CpioConstants.FORMAT_NEW_CRC<br/>
-     * CpioConstants.FORMAT_OLD_BINARY<br/>
-     * CpioConstants.FORMAT_OLD_ASCII<br/>
+     * Possible format values are:
+     * <pre>
+     * CpioConstants.FORMAT_NEW
+     * CpioConstants.FORMAT_NEW_CRC
+     * CpioConstants.FORMAT_OLD_BINARY
+     * CpioConstants.FORMAT_OLD_ASCII
+     * </pre>
      * 
      * @since 1.1
      */
@@ -281,13 +282,14 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      *            The name of this entry.
      * @param size
      *            The size of this entry
-     * <br/>
-     * Possible format values are:
      * <p>
-     * CpioConstants.FORMAT_NEW<br/>
-     * CpioConstants.FORMAT_NEW_CRC<br/>
-     * CpioConstants.FORMAT_OLD_BINARY<br/>
-     * CpioConstants.FORMAT_OLD_ASCII<br/>
+     * Possible format values are:
+     * <pre>
+     * CpioConstants.FORMAT_NEW
+     * CpioConstants.FORMAT_NEW_CRC
+     * CpioConstants.FORMAT_OLD_BINARY
+     * CpioConstants.FORMAT_OLD_ASCII
+     * </pre>
      * 
      * @since 1.1
      */
@@ -321,30 +323,29 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      *            The file to gather information from.
      * @param entryName
      *            The name of this entry.
-     * <br/>
-     * Possible format values are:
      * <p>
-     * CpioConstants.FORMAT_NEW<br/>
-     * CpioConstants.FORMAT_NEW_CRC<br/>
-     * CpioConstants.FORMAT_OLD_BINARY<br/>
-     * CpioConstants.FORMAT_OLD_ASCII<br/>
+     * Possible format values are:
+     * <pre>
+     * CpioConstants.FORMAT_NEW
+     * CpioConstants.FORMAT_NEW_CRC
+     * CpioConstants.FORMAT_OLD_BINARY
+     * CpioConstants.FORMAT_OLD_ASCII
+     * </pre>
      * 
      * @since 1.1
      */
     public CpioArchiveEntry(final short format, File inputFile,
                             String entryName) {
         this(format, entryName, inputFile.isFile() ? inputFile.length() : 0);
-        long mode=0;
         if (inputFile.isDirectory()){
-            mode |= C_ISDIR;
+            setMode(C_ISDIR);
         } else if (inputFile.isFile()){
-            mode |= C_ISREG;
+            setMode(C_ISREG);
         } else {
             throw new IllegalArgumentException("Cannot determine type of file "
                                                + inputFile.getName());
         }
         // TODO set other fields as needed
-        setMode(mode);
         setTime(inputFile.lastModified() / 1000);
     }
 
@@ -468,7 +469,10 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      */
     public int getHeaderPadCount(){
         if (this.alignmentBoundary == 0) { return 0; }
-        int size = this.headerSize+this.name.length()+1; // Name has terminating null
+        int size = this.headerSize + 1;  // Name has terminating null
+        if (name != null) {
+            size += name.length();
+        }
         int remain = size % this.alignmentBoundary;
         if (remain > 0){
             return this.alignmentBoundary - remain;
@@ -525,7 +529,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      */
     public long getNumberOfLinks() {
         return nlink == 0 ?
-            (isDirectory() ? 2 : 1)
+            isDirectory() ? 2 : 1
             : nlink;
     }
 
@@ -664,7 +668,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
 
     /**
      * Set the checksum. The checksum is calculated by adding all bytes of a
-     * file to transfer (crc += buf[pos] & 0xFF).
+     * file to transfer (crc += buf[pos] &amp; 0xFF).
      * 
      * @param chksum
      *            The checksum to set.
@@ -861,7 +865,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     public int hashCode() {
         final int prime = 31;
         int result = 1;
-        result = prime * result + ((name == null) ? 0 : name.hashCode());
+        result = prime * result + (name == null ? 0 : name.hashCode());
         return result;
     }
 
