@@ -34,17 +34,17 @@ import org.apache.commons.compress.utils.IOUtils;
  * CPIOArchiveInputStream is a stream for reading cpio streams. All formats of
  * cpio are supported (old ascii, old binary, new portable format and the new
  * portable format with crc).
- * <p/>
- * <p/>
+ *
+ * <p>
  * The stream can be read by extracting a cpio entry (containing all
  * informations about a entry) and afterwards reading from the stream the file
  * specified by the entry.
- * <p/>
- * <code><pre>
+ * </p>
+ * <pre>
  * CPIOArchiveInputStream cpioIn = new CPIOArchiveInputStream(
  *         new FileInputStream(new File(&quot;test.cpio&quot;)));
  * CPIOArchiveEntry cpioEntry;
- * <p/>
+ *
  * while ((cpioEntry = cpioIn.getNextEntry()) != null) {
  *     System.out.println(cpioEntry.getName());
  *     int tmp;
@@ -55,13 +55,13 @@ import org.apache.commons.compress.utils.IOUtils;
  *     System.out.println(buf.toString());
  * }
  * cpioIn.close();
- * </pre></code>
- * <p/>
+ * </pre>
+ * <p>
  * Note: This implementation should be compatible to cpio 2.5
  * 
- * This class uses mutable fields and is not considered to be threadsafe.
+ * <p>This class uses mutable fields and is not considered to be threadsafe.
  * 
- * Based on code from the jRPM project (jrpm.sourceforge.net)
+ * <p>Based on code from the jRPM project (jrpm.sourceforge.net)
  */
 
 public class CpioArchiveInputStream extends ArchiveInputStream implements
@@ -91,7 +91,10 @@ public class CpioArchiveInputStream extends ArchiveInputStream implements
     /**
      * The encoding to use for filenames and labels.
      */
-    private final ZipEncoding encoding;
+    private final ZipEncoding zipEncoding;
+
+    // the provided encoding (for unit tests)
+    final String encoding;
 
     /**
      * Construct the cpio input stream with a blocksize of {@link
@@ -150,13 +153,14 @@ public class CpioArchiveInputStream extends ArchiveInputStream implements
     public CpioArchiveInputStream(final InputStream in, int blockSize, String encoding) {
         this.in = in;
         this.blockSize = blockSize;
-        this.encoding = ZipEncodingHelper.getZipEncoding(encoding);
+        this.encoding = encoding;
+        this.zipEncoding = ZipEncodingHelper.getZipEncoding(encoding);
     }
 
     /**
      * Returns 0 after EOF has reached for the current entry data, otherwise
      * always return 1.
-     * <p/>
+     * <p>
      * Programs should not count on this method to return the actual number of
      * bytes that could be read without blocking.
      * 
@@ -197,12 +201,11 @@ public class CpioArchiveInputStream extends ArchiveInputStream implements
      *             occurred
      */
     private void closeEntry() throws IOException {
-        ensureOpen();
-        while (read(this.tmpbuf, 0, this.tmpbuf.length) != -1) { // NOPMD
+        // the skip implementation of this class will not skip more
+        // than Integer.MAX_VALUE bytes
+        while (skip((long) Integer.MAX_VALUE) == Integer.MAX_VALUE) { // NOPMD
             // do nothing
         }
-
-        this.entryEOF = true;
     }
 
     /**
@@ -445,7 +448,7 @@ public class CpioArchiveInputStream extends ArchiveInputStream implements
         byte tmpBuffer[] = new byte[length - 1];
         readFully(tmpBuffer, 0, tmpBuffer.length);
         this.in.read();
-        return encoding.decode(tmpBuffer);
+        return zipEncoding.decode(tmpBuffer);
     }
 
     /**
@@ -457,7 +460,7 @@ public class CpioArchiveInputStream extends ArchiveInputStream implements
      * @throws IOException
      *             if an I/O error has occurred
      * @throws IllegalArgumentException
-     *             if n < 0
+     *             if n &lt; 0
      */
     @Override
     public long skip(final long n) throws IOException {
@@ -516,6 +519,9 @@ public class CpioArchiveInputStream extends ArchiveInputStream implements
      * Octal Binary value:
      * 
      * 070707 - MAGIC_OLD_BINARY (held as a short) = 0x71C7 or 0xC771
+     * @param signature data to match
+     * @param length length of data
+     * @return whether the buffer seems to contain CPIO data
      */
     public static boolean matches(byte[] signature, int length) {
         if (length < 6) {
