@@ -62,8 +62,7 @@ public class TarUtils {
                 final int length = buffer.length;
                 StringBuilder result = new StringBuilder(length);
 
-                for (int i = 0; i < length; ++i) {
-                    byte b = buffer[i];
+                for (byte b : buffer) {
                     if (b == 0) { // Trailing null
                         break;
                     }
@@ -281,6 +280,7 @@ public class TarUtils {
      * @param encoding name of the encoding to use for file names
      * @since 1.4
      * @return The entry name.
+     * @throws IOException on error
      */
     public static String parseName(byte[] buffer, final int offset,
                                    final int length,
@@ -346,6 +346,7 @@ public class TarUtils {
      * @param encoding name of the encoding to use for file names
      * @since 1.4
      * @return The updated offset, i.e. offset + length
+     * @throws IOException on error
      */
     public static int formatNameBytes(String name, byte[] buf, final int offset,
                                       final int length,
