@@ -18,9 +18,9 @@
 package org.apache.commons.compress.archivers.zip;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.zip.ZipException;
 
 /**
@@ -38,8 +38,10 @@ public class ExtraFieldUtils {
     private static final Map<ZipShort, Class<?>> implementations;
 
     static {
-        implementations = new HashMap<ZipShort, Class<?>>();
+        implementations = new ConcurrentHashMap<ZipShort, Class<?>>();
         register(AsiExtraField.class);
+        register(X5455_ExtendedTimestamp.class);
+        register(X7875_NewUnix.class);
         register(JarMarker.class);
         register(UnicodePathExtraField.class);
         register(UnicodeCommentExtraField.class);
@@ -67,12 +69,12 @@ public class ExtraFieldUtils {
     }
 
     /**
-     * Create an instance of the approriate ExtraField, falls back to
+     * Create an instance of the appropriate ExtraField, falls back to
      * {@link UnrecognizedExtraField UnrecognizedExtraField}.
      * @param headerId the header identifier
-     * @return an instance of the appropiate ExtraField
+     * @return an instance of the appropriate ExtraField
      * @exception InstantiationException if unable to instantiate the class
-     * @exception IllegalAccessException if not allowed to instatiate the class
+     * @exception IllegalAccessException if not allowed to instantiate the class
      */
     public static ZipExtraField createExtraField(ZipShort headerId)
         throws InstantiationException, IllegalAccessException {
@@ -132,7 +134,7 @@ public class ExtraFieldUtils {
         LOOP:
         while (start <= data.length - WORD) {
             ZipShort headerId = new ZipShort(data, start);
-            int length = (new ZipShort(data, start + 2)).getValue();
+            int length = new ZipShort(data, start + 2).getValue();
             if (start + WORD + length > data.length) {
                 switch(onUnparseableData.getKey()) {
                 case UnparseableExtraField.THROW_KEY:
@@ -174,11 +176,11 @@ public class ExtraFieldUtils {
                 }
                 v.add(ze);
             } catch (InstantiationException ie) {
-                throw new ZipException(ie.getMessage());
+                throw (ZipException) new ZipException(ie.getMessage()).initCause(ie);
             } catch (IllegalAccessException iae) {
-                throw new ZipException(iae.getMessage());
+                throw (ZipException) new ZipException(iae.getMessage()).initCause(iae);
             }
-            start += (length + WORD);
+            start += length + WORD;
         }
 
         ZipExtraField[] result = new ZipExtraField[v.size()];
@@ -208,13 +210,18 @@ public class ExtraFieldUtils {
                              0, result, start, 2);
             System.arraycopy(data[i].getLocalFileDataLength().getBytes(),
                              0, result, start + 2, 2);
+            start += WORD;
             byte[] local = data[i].getLocalFileDataData();
-            System.arraycopy(local, 0, result, start + WORD, local.length);
-            start += (local.length + WORD);
+            if (local != null) {
+                System.arraycopy(local, 0, result, start, local.length);
+                start += local.length;
+            }
         }
         if (lastIsUnparseableHolder) {
             byte[] local = data[data.length - 1].getLocalFileDataData();
-            System.arraycopy(local, 0, result, start, local.length);
+            if (local != null) {
+                System.arraycopy(local, 0, result, start, local.length);
+            }
         }
         return result;
     }
@@ -241,13 +248,18 @@ public class ExtraFieldUtils {
                              0, result, start, 2);
             System.arraycopy(data[i].getCentralDirectoryLength().getBytes(),
                              0, result, start + 2, 2);
+            start += WORD;
             byte[] local = data[i].getCentralDirectoryData();
-            System.arraycopy(local, 0, result, start + WORD, local.length);
-            start += (local.length + WORD);
+            if (local != null) {
+                System.arraycopy(local, 0, result, start, local.length);
+                start += local.length;
+            }
         }
         if (lastIsUnparseableHolder) {
             byte[] local = data[data.length - 1].getCentralDirectoryData();
-            System.arraycopy(local, 0, result, start, local.length);
+            if (local != null) {
+                System.arraycopy(local, 0, result, start, local.length);
+            }
         }
         return result;
     }
@@ -300,6 +312,7 @@ public class ExtraFieldUtils {
 
         /**
          * Key of the action to take.
+         * @return the key
          */
         public int getKey() { return key; }
     }
