@@ -23,7 +23,6 @@ import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
-import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.zip.ZipException;
 
@@ -32,8 +31,7 @@ import java.util.zip.ZipException;
  * access to the internal and external file attributes.
  *
  * <p>The extra data is expected to follow the recommendation of
- * {@link <a href="http://www.pkware.com/documents/casestudies/APPNOTE.TXT">
- * APPNOTE.txt</a>}:</p>
+ * <a href="http://www.pkware.com/documents/casestudies/APPNOTE.TXT">APPNOTE.TXT</a>:</p>
  * <ul>
  *   <li>the extra byte array consists of a sequence of extra fields</li>
  *   <li>each extra fields starts by a two byte header id followed by
@@ -54,6 +52,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     public static final int PLATFORM_UNIX = 3;
     public static final int PLATFORM_FAT  = 0;
+    public static final int CRC_UNKNOWN = -1;
     private static final int SHORT_MASK = 0xFFFF;
     private static final int SHORT_SHIFT = 16;
     private static final byte[] EMPTY = new byte[0];
@@ -68,7 +67,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-93"
      *        >COMPRESS-93</a>
      */
-    private int method = -1;
+    private int method = ZipMethod.UNKNOWN_CODE;
 
     /**
      * The {@link java.util.zip.ZipEntry#setSize} method in the base
@@ -81,11 +80,12 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     private int internalAttributes = 0;
     private int platform = PLATFORM_FAT;
     private long externalAttributes = 0;
-    private LinkedHashMap<ZipShort, ZipExtraField> extraFields = null;
+    private ZipExtraField[] extraFields;
     private UnparseableExtraFieldData unparseableExtra = null;
     private String name = null;
     private byte[] rawName = null;
     private GeneralPurposeBit gpb = new GeneralPurposeBit();
+    private static final ZipExtraField[] noExtraFields = new ZipExtraField[0];
 
     /**
      * Creates a new zip entry with the specified name.
@@ -138,7 +138,11 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         this((java.util.zip.ZipEntry) entry);
         setInternalAttributes(entry.getInternalAttributes());
         setExternalAttributes(entry.getExternalAttributes());
-        setExtraFields(entry.getExtraFields(true));
+        setExtraFields(getAllExtraFieldsNoCopy());
+        setPlatform(entry.getPlatform());
+        GeneralPurposeBit other = entry.getGeneralPurposeBit();
+        setGeneralPurposeBit(other == null ? null :
+                             (GeneralPurposeBit) other.clone());
     }
 
     /**
@@ -155,6 +159,8 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * the file is a directory.  If the file is not a directory a
      * potential trailing forward slash will be stripped from the
      * entry name.</p>
+     * @param inputFile file to create the entry from
+     * @param entryName name of the entry
      */
     public ZipArchiveEntry(File inputFile, String entryName) {
         this(inputFile.isDirectory() && !entryName.endsWith("/") ? 
@@ -176,7 +182,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
         e.setInternalAttributes(getInternalAttributes());
         e.setExternalAttributes(getExternalAttributes());
-        e.setExtraFields(getExtraFields(true));
+        e.setExtraFields(getAllExtraFieldsNoCopy());
         return e;
     }
 
@@ -212,6 +218,10 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     /**
      * Retrieves the internal file attributes.
      *
+     * <p><b>Note</b>: {@link ZipArchiveInputStream} is unable to fill
+     * this field, you must use {@link ZipFile} if you want to read
+     * entries using this attribute.</p>
+     *
      * @return the internal file attributes
      */
     public int getInternalAttributes() {
@@ -228,6 +238,11 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     /**
      * Retrieves the external file attributes.
+     *
+     * <p><b>Note</b>: {@link ZipArchiveInputStream} is unable to fill
+     * this field, you must use {@link ZipFile} if you want to read
+     * entries using this attribute.</p>
+     *
      * @return the external file attributes
      */
     public long getExternalAttributes() {
@@ -303,23 +318,30 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @param fields an array of extra fields
      */
     public void setExtraFields(ZipExtraField[] fields) {
-        extraFields = new LinkedHashMap<ZipShort, ZipExtraField>();
+        List<ZipExtraField> newFields = new ArrayList<ZipExtraField>();
         for (ZipExtraField field : fields) {
             if (field instanceof UnparseableExtraFieldData) {
                 unparseableExtra = (UnparseableExtraFieldData) field;
             } else {
-                extraFields.put(field.getHeaderId(), field);
+                newFields.add( field);
             }
         }
+        extraFields = newFields.toArray(new ZipExtraField[newFields.size()]);
         setExtra();
     }
 
     /**
      * Retrieves all extra fields that have been parsed successfully.
+     *
+     * <p><b>Note</b>: The set of extra fields may be incomplete when
+     * {@link ZipArchiveInputStream} has been used as some extra
+     * fields use the central directory to store additional
+     * information.</p>
+     *
      * @return an array of the extra fields
      */
     public ZipExtraField[] getExtraFields() {
-        return getExtraFields(false);
+        return getParseableExtraFields();
     }
 
     /**
@@ -332,19 +354,58 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @since 1.1
      */
     public ZipExtraField[] getExtraFields(boolean includeUnparseable) {
-        if (extraFields == null) {
-            return !includeUnparseable || unparseableExtra == null
-                ? new ZipExtraField[0]
-                : new ZipExtraField[] { unparseableExtra };
-        }
-        List<ZipExtraField> result =
-            new ArrayList<ZipExtraField>(extraFields.values());
-        if (includeUnparseable && unparseableExtra != null) {
-            result.add(unparseableExtra);
-        }
-        return result.toArray(new ZipExtraField[0]);
+        return includeUnparseable ?
+                getAllExtraFields() :
+                getParseableExtraFields();
     }
 
+    private ZipExtraField[] getParseableExtraFieldsNoCopy() {
+        if (extraFields == null) {
+            return noExtraFields;
+        }
+        return extraFields;
+    }
+
+    private ZipExtraField[] getParseableExtraFields() {
+        final ZipExtraField[] parseableExtraFields = getParseableExtraFieldsNoCopy();
+        return (parseableExtraFields == extraFields) ? copyOf(parseableExtraFields) : parseableExtraFields;
+    }
+
+    /**
+     * Get all extra fields, including unparseable ones.
+     * @return An array of all extra fields. Not necessarily a copy of internal data structures, hence private method
+     */
+    private ZipExtraField[] getAllExtraFieldsNoCopy() {
+        if (extraFields == null) {
+            return getUnparseableOnly();
+        }
+        return unparseableExtra != null ? getMergedFields() : extraFields;
+    }
+
+    private ZipExtraField[] copyOf(ZipExtraField[] src){
+        return copyOf(src, src.length);
+    }
+
+    private ZipExtraField[] copyOf(ZipExtraField[] src, int length) {
+        ZipExtraField[] cpy = new ZipExtraField[length];
+        System.arraycopy(src, 0, cpy, 0, Math.min(src.length, length));
+        return cpy;
+    }
+
+    private ZipExtraField[] getMergedFields() {
+        final ZipExtraField[] zipExtraFields = copyOf(extraFields, extraFields.length + 1);
+        zipExtraFields[extraFields.length] = unparseableExtra;
+        return zipExtraFields;
+    }
+
+    private ZipExtraField[] getUnparseableOnly() {
+        return unparseableExtra == null ? noExtraFields : new ZipExtraField[] { unparseableExtra };
+    }
+
+    private ZipExtraField[] getAllExtraFields() {
+        final ZipExtraField[] allExtraFieldsNoCopy = getAllExtraFieldsNoCopy();
+        return (allExtraFieldsNoCopy == extraFields) ? copyOf( allExtraFieldsNoCopy) : allExtraFieldsNoCopy;
+    }
     /**
      * Adds an extra field - replacing an already present extra field
      * of the same type.
@@ -358,9 +419,15 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
             unparseableExtra = (UnparseableExtraFieldData) ze;
         } else {
             if (extraFields == null) {
-                extraFields = new LinkedHashMap<ZipShort, ZipExtraField>();
+                extraFields = new ZipExtraField[]{ ze};
+            } else {
+                if (getExtraField(ze.getHeaderId())!= null){
+                    removeExtraField(ze.getHeaderId());
+                }
+                final ZipExtraField[] zipExtraFields = copyOf(extraFields, extraFields.length + 1);
+                zipExtraFields[zipExtraFields.length -1] = ze;
+                extraFields = zipExtraFields;
             }
-            extraFields.put(ze.getHeaderId(), ze);
         }
         setExtra();
     }
@@ -376,12 +443,15 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         if (ze instanceof UnparseableExtraFieldData) {
             unparseableExtra = (UnparseableExtraFieldData) ze;
         } else {
-            LinkedHashMap<ZipShort, ZipExtraField> copy = extraFields;
-            extraFields = new LinkedHashMap<ZipShort, ZipExtraField>();
-            extraFields.put(ze.getHeaderId(), ze);
-            if (copy != null) {
-                copy.remove(ze.getHeaderId());
-                extraFields.putAll(copy);
+            if (getExtraField(ze.getHeaderId()) != null){
+                removeExtraField(ze.getHeaderId());
+            }
+            ZipExtraField[] copy = extraFields;
+            int newLen = extraFields != null ? extraFields.length + 1: 1;
+            extraFields = new ZipExtraField[newLen];
+            extraFields[0] = ze;
+            if (copy != null){
+                System.arraycopy(copy, 0, extraFields, 1, extraFields.length - 1);
             }
         }
         setExtra();
@@ -395,9 +465,17 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
         if (extraFields == null) {
             throw new java.util.NoSuchElementException();
         }
-        if (extraFields.remove(type) == null) {
+
+        List<ZipExtraField> newResult = new ArrayList<ZipExtraField>();
+        for (ZipExtraField extraField : extraFields) {
+            if (!type.equals(extraField.getHeaderId())){
+                newResult.add( extraField);
+            }
+        }
+        if (extraFields.length == newResult.size()) {
             throw new java.util.NoSuchElementException();
         }
+        extraFields = newResult.toArray(new ZipExtraField[newResult.size()]);
         setExtra();
     }
 
@@ -417,11 +495,16 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
     /**
      * Looks up an extra field by its header id.
      *
+     * @param type the header id
      * @return null if no such field exists.
      */
     public ZipExtraField getExtraField(ZipShort type) {
         if (extraFields != null) {
-            return extraFields.get(type);
+            for (ZipExtraField extraField : extraFields) {
+                if (type.equals(extraField.getHeaderId())) {
+                    return extraField;
+                }
+            }
         }
         return null;
     }
@@ -466,11 +549,12 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * modify super's data directly.
      */
     protected void setExtra() {
-        super.setExtra(ExtraFieldUtils.mergeLocalFileDataData(getExtraFields(true)));
+        super.setExtra(ExtraFieldUtils.mergeLocalFileDataData(getAllExtraFieldsNoCopy()));
     }
 
     /**
      * Sets the central directory part of extra fields.
+     * @param b an array of bytes to be parsed into extra fields
      */
     public void setCentralDirectoryExtra(byte[] b) {
         try {
@@ -497,7 +581,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * @return the central directory extra data
      */
     public byte[] getCentralDirectoryExtra() {
-        return ExtraFieldUtils.mergeCentralDirectoryData(getExtraFields(true));
+        return ExtraFieldUtils.mergeCentralDirectoryData(getAllExtraFieldsNoCopy());
     }
 
     /**
@@ -524,7 +608,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      */
     protected void setName(String name) {
         if (name != null && getPlatform() == PLATFORM_FAT
-            && name.indexOf("/") == -1) {
+            && !name.contains("/")) {
             name = name.replace('\\', '/');
         }
         this.name = name;
@@ -532,6 +616,11 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     /**
      * Gets the uncompressed size of the entry data.
+     *
+     * <p><b>Note</b>: {@link ZipArchiveInputStream} may create
+     * entries that return {@link #SIZE_UNKNOWN SIZE_UNKNOWN} as long
+     * as the entry hasn't been read completely.</p>
+     *
      * @return the entry size
      */
     @Override
@@ -574,6 +663,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
      * <p>This method will return null if this instance has not been
      * read from an archive.</p>
      *
+     * @return the raw name bytes
      * @since 1.2
      */
     public byte[] getRawName() {
@@ -601,6 +691,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     /**
      * The "general purpose bit" field.
+     * @return the general purpose bit
      * @since 1.1
      */
     public GeneralPurposeBit getGeneralPurposeBit() {
@@ -609,6 +700,7 @@ public class ZipArchiveEntry extends java.util.zip.ZipEntry
 
     /**
      * The "general purpose bit" field.
+     * @param b the general purpose bit
      * @since 1.1
      */
     public void setGeneralPurposeBit(GeneralPurposeBit b) {
