@@ -27,6 +27,8 @@ import java.io.BufferedInputStream;
 import java.io.FileInputStream;
 import java.io.InputStream;
 import java.io.IOException;
+
+import org.apache.commons.compress.utils.IOUtils;
 import org.junit.Test;
 
 public class ZipArchiveInputStreamTest {
@@ -120,4 +122,51 @@ public class ZipArchiveInputStreamTest {
             zae = in.getNextZipEntry();
         }
     }
+
+    @Test
+    public void testUnshrinkEntry() throws Exception {
+        ZipArchiveInputStream in = new ZipArchiveInputStream(new FileInputStream(getFile("SHRUNK.ZIP")));
+        
+        ZipArchiveEntry entry = in.getNextZipEntry();
+        assertEquals("method", ZipMethod.UNSHRINKING.getCode(), entry.getMethod());
+        assertTrue(in.canReadEntryData(entry));
+        
+        FileInputStream original = new FileInputStream(getFile("test1.xml"));
+        try {
+            assertArrayEquals(IOUtils.toByteArray(original), IOUtils.toByteArray(in));
+        } finally {
+            original.close();
+        }
+        
+        entry = in.getNextZipEntry();
+        assertEquals("method", ZipMethod.UNSHRINKING.getCode(), entry.getMethod());
+        assertTrue(in.canReadEntryData(entry));
+        
+        original = new FileInputStream(getFile("test2.xml"));
+        try {
+            assertArrayEquals(IOUtils.toByteArray(original), IOUtils.toByteArray(in));
+        } finally {
+            original.close();
+        }
+    }
+
+
+    /**
+     * Test case for 
+     * <a href="https://issues.apache.org/jira/browse/COMPRESS-264"
+     * >COMPRESS-264</a>.
+     */
+    @Test
+    public void testReadingOfFirstStoredEntry() throws Exception {
+        ZipArchiveInputStream in = new ZipArchiveInputStream(new FileInputStream(getFile("COMPRESS-264.zip")));
+        
+        try {
+            ZipArchiveEntry ze = in.getNextZipEntry();
+            assertEquals(5, ze.getSize());
+            assertArrayEquals(new byte[] {'d', 'a', 't', 'a', '\n'},
+                              IOUtils.toByteArray(in));
+        } finally {
+            in.close();
+        }
+    }
 }
