@@ -18,6 +18,8 @@
  */
 package org.apache.commons.compress.changes;
 
+import static org.junit.Assert.*;
+
 import java.io.BufferedInputStream;
 import java.io.BufferedReader;
 import java.io.File;
@@ -38,6 +40,8 @@ import org.apache.commons.compress.archivers.cpio.CpioArchiveEntry;
 import org.apache.commons.compress.archivers.jar.JarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.zip.ZipArchiveEntry;
+import org.apache.commons.compress.archivers.zip.ZipFile;
+import org.junit.Test;
 
 /**
  * Checks several ChangeSet business logics.
@@ -73,6 +77,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testAddChangeTwice() throws Exception {
         InputStream in = null;
         InputStream in2 = null;
@@ -107,6 +112,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testAddChangeTwiceWithoutReplace() throws Exception {
         InputStream in = null;
         InputStream in2 = null;
@@ -142,6 +148,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteDir() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -183,6 +190,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteDir2() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -224,6 +232,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteDir3() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -265,6 +274,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFile() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -307,6 +317,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFile2() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -350,6 +361,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeletePlusAddSame() throws Exception {
         final String archivename = "zip";
         File input = this.createArchive(archivename);
@@ -421,6 +433,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testChangeSetResults() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -484,6 +497,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeletePlusAdd() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -530,6 +544,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFromAndAddToZip() throws Exception {
         final String archivename = "zip";
         File input = this.createArchive(archivename);
@@ -571,12 +586,58 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         this.checkArchiveContent(result, archiveList);
     }
 
+    /**
+     * Adds a file to a zip archive. Deletes an other file.
+     * 
+     * @throws Exception
+     */
+    @Test
+    public void testDeleteFromAndAddToZipUsingZipFilePerform() throws Exception {
+        final String archivename = "zip";
+        File input = this.createArchive(archivename);
+
+        ArchiveOutputStream out = null;
+        ZipFile ais = null;
+        File result = File.createTempFile("test", "."+archivename);
+        result.deleteOnExit();
+        try {
+
+            ais = new ZipFile(input);
+            out = factory.createArchiveOutputStream(archivename,
+                    new FileOutputStream(result));
+
+            ChangeSet changes = new ChangeSet();
+
+            final File file1 = getFile("test.txt");
+            ArchiveEntry entry = new ZipArchiveEntry("blub/test.txt");
+            changes.add(entry, new FileInputStream(file1));
+            archiveList.add("blub/test.txt");
+
+            changes.delete("testdata/test1.xml");
+            archiveListDelete("testdata/test1.xml");
+
+            ChangeSetPerformer performer = new ChangeSetPerformer(changes);
+            performer.perform(ais, out);
+
+        } finally {
+            if (out != null) {
+                out.close();
+            }
+            if (ais != null) {
+                ais.close();
+            }
+        }
+
+        this.checkArchiveContent(result, archiveList);
+    }
+
     /**
      * add blub/test.txt + delete blub Should add blub/test.txt and delete it
      * afterwards. In this example, the archive should stay untouched.
      * 
      * @throws Exception
      */
+    @Test
     public void testAddDeleteAdd() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -625,6 +686,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteAddDelete() throws Exception {
         final String archivename = "cpio";
         File input = this.createArchive(archivename);
@@ -674,6 +736,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFromZip() throws Exception {
         ArchiveOutputStream out = null;
         ArchiveInputStream ais = null;
@@ -714,6 +777,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFromTar() throws Exception {
         ArchiveOutputStream out = null;
         ArchiveInputStream ais = null;
@@ -751,6 +815,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFromJar() throws Exception {
         ArchiveOutputStream out = null;
         ArchiveInputStream ais = null;
@@ -786,6 +851,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
         this.checkArchiveContent(temp, expected);
     }
 
+    @Test
     public void testDeleteFromAndAddToTar() throws Exception {
         ArchiveOutputStream out = null;
         ArchiveInputStream ais = null;
@@ -839,6 +905,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFromAndAddToJar() throws Exception {
         ArchiveOutputStream out = null;
         ArchiveInputStream ais = null;
@@ -884,6 +951,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFromAr() throws Exception {
         ArchiveOutputStream out = null;
         ArchiveInputStream ais = null;
@@ -922,6 +990,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteFromAndAddToAr() throws Exception {
         ArchiveOutputStream out = null;
         ArchiveInputStream ais = null;
@@ -970,6 +1039,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testRenameAndDelete() throws Exception {
     }
 
@@ -983,6 +1053,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testAddMoveDelete() throws Exception {
     }
 
@@ -991,6 +1062,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testAddToEmptyArchive() throws Exception {
         final String archivename = "zip";
         File input = this.createEmptyArchive(archivename);
@@ -1036,6 +1108,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testDeleteAddToOneFileArchive() throws Exception {
         final String archivename = "zip";
         File input = this.createSingleEntryArchive(archivename);
@@ -1084,6 +1157,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testAddDeleteToOneFileArchive() throws Exception {
         final String archivename = "cpio";
         File input = this.createSingleEntryArchive(archivename);
@@ -1133,6 +1207,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testAddAllreadyExistingWithReplaceTrue() throws Exception {
         final String archivename = "zip";
         File input = this.createArchive(archivename);
@@ -1177,6 +1252,7 @@ public final class ChangeSetTestCase extends AbstractTestCase {
      * 
      * @throws Exception
      */
+    @Test
     public void testAddAllreadyExistingWithReplaceFalse() throws Exception {
         final String archivename = "zip";
         File input = this.createArchive(archivename);
